Code coverage report for js/richPromise.tsx

# All files / js richPromise.tsx

66.67% Statements 2/3
100% Branches 0/0
0% Functions 0/1
66.67% Lines 2/3

Press n or j to go to the next uncovered block, b, p or k for the previous block.

    1
    2
    3
    4
    5
    6
    71x
    1x

     import ErrorDialog from "./dialogs/errorDialog";
    import dialogSystem from "./dialogSystem";

    export function bringUpDialog(error: unknown) {
      dialogSystem.showDialog(ErrorDialog, { error }, false);
    }